<?php 
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Add main menu and a submenu for Skelet plugin
 */
function skelet_admin_pages() {
    // Add main menu
    add_menu_page( 
        'Skelet Ai', // page title
        'Skelet Ai', // menu title
        'manage_options', // capability
        'skelet', // menu slug
        'skelet_render_page', // display content using the class
        'dashicons-welcome-widgets-menus', // icon url (default is empty)
        3
    );

    // Add submenu under the main menu
    add_submenu_page(
        'skelet', // parent slug
        'Settings', // page title
        'Settings', // menu title
        'manage_options', // capability
        'skelet-settings', // menu slug
        'skelet_render_settings' // function to display the page content
    );

    // Add submenu under the main menu
    add_submenu_page(
        'skelet', // parent slug
        'Details', // page title
        'Details', // menu title
        'manage_options', // capability
        'skelet-info', // menu slug
        'skelet_render_info' // function to display the page content
    );
}
add_action( 'admin_menu', 'skelet_admin_pages' );

function skelet_render_page() {    
    $generate_full_blog = SKELET_TEMPLATES_DIR . '/skelet_full_blog_generator.php';
    $row_exists = Skelet_Plugin_Status::row_exists();
    ?>
    <div class="wrap">                
        <h2>Skelet Ai</h2>
        <?php if($row_exists):?>
            <h3>Full Blog Generator</h3>
            <?php include($generate_full_blog);?>
        <?php else:?> 
            <p>To begin generating content, please activate the plugin by visiting the settings page: <a href="/wp-admin/admin.php?page=skelet-settings">Activate Plugin</a>.</p>
        <?php endif;?>
        <div id="skelet_response" class="skelet_response"></div>
    </div>
    <?php
}

function skelet_render_settings() {
    $row_exists = Skelet_Plugin_Status::row_exists();
    ?>
    <div class="wrap">
        <h2>Settings</h2>   
        <?php
            $activation_form = SKELET_TEMPLATES_DIR . '/skelet_api_verification_form.php';
            $deactivation_form = SKELET_TEMPLATES_DIR . '/skelet_api_deactivation_form.php';
        ?>
        <?php if(!$row_exists):?>
            <p>If you don't have an API key, you can generate one by following these steps: <br/>
                1- Create an account at <a href="https://skelet.ai" target="_blank">skelet.ai</a> <br/>
                2- Go to your profile and generate an API key.<br/>
                3- Copy the API key.<br/>
                4- Return to the plugin activation page and paste it.<br/>
                5- You're all set! Enjoy!
            </p>
            <?php include($activation_form);?>
        <?php else:?>
            <p>To deactivate the plugin, please click the button below</p>
            <?php include($deactivation_form);?>
        <?php endif;?>
        <div id="skelet_response" class="skelet_response"></div>
    </div>
    <?php
}

function skelet_render_info() {
    $informations = SKELET_TEMPLATES_DIR . '/skelet_informations.php';
    ?>
    <div class="wrap">
        <div class="skelet_details">
            <h1>Plugin Details:</h1>
            <?php include($informations);?>
            <a class="button-primary" href="/wp-admin/admin.php?page=skelet">Start Generate</a>
        </div>
    </div>
    <?php
}
