<?php 
if ( ! defined( 'ABSPATH' ) ) exit;

function skelet_verify_api_key() {
    if (isset($_POST['skelet_nonce'])) {
        $skelet_nonce = sanitize_text_field(wp_unslash($_POST['skelet_nonce']));
        
        if (wp_verify_nonce($skelet_nonce, 'skelet_nonce')) {

            if (isset($_POST['api_key'])) {

                if (isset($_POST['status'])) {
                    $status = sanitize_text_field(wp_unslash($_POST['status']));
                    
                    if($status === 'deactivate'){
                        Skelet_Plugin_Status::delete();
                        return wp_send_json_success('Plugin deactivated successfully.');
                    }
                }

                $api_key = sanitize_text_field(wp_unslash($_POST['api_key']));
                $response = wp_remote_get("https://skelet.ai/api/endpoints/skelet-api/verify-api-key?apiKey=$api_key", array(
                    'timeout' => 300, // Set timeout to 5 minutes
                ));

                if (is_wp_error($response)) {
                    return wp_send_json_error('Unable to contact skelet.ai.');
                } else {
                    $response_body = wp_remote_retrieve_body($response);
                    $response_data = json_decode($response_body, true);

                    if($response_data['message'] === 'No Api Key Found'){
                        return wp_send_json_error('No API Key Found.');
                    }

                    if($response_data['message'] === 'Api Key Valid'){
                        Skelet_Plugin_Status::add($api_key);
                        return wp_send_json_success('API validated successfully.');
                    }

                    if($response_data['message'] === 'Your credit balance is too low. Please upgrade your subscription plan.'){
                        return wp_send_json_error('Your credit balance is too low. Please upgrade your subscription plan.');
                    }
                    
                    return wp_send_json_success('An error occurred. Please try again later.');
                }
            } else {
                wp_send_json_error('No API key provided.');
            }
        }
    }
    wp_die();
}
add_action('wp_ajax_verify_skelet_api_key', 'skelet_verify_api_key');
add_action('wp_ajax_nopriv_verify_skelet_api_key', 'skelet_verify_api_key');

function skelet_generate_content() {
    if (isset($_POST['skelet_nonce'])) {
        $skelet_nonce = sanitize_text_field(wp_unslash($_POST['skelet_nonce']));
        
        if (wp_verify_nonce($skelet_nonce, 'skelet_nonce')) {
            if (isset($_POST['title'])) {

                $title = sanitize_text_field(wp_unslash($_POST['title']));

                if (isset($_POST['keywords'])) {
                    $keywords = sanitize_text_field(wp_unslash($_POST['keywords']));
                }
                if (isset($_POST['goal'])) {
                    $goal = sanitize_text_field(wp_unslash($_POST['goal']));
                }
                if (isset($_POST['tone'])) {
                    $tone = sanitize_text_field(wp_unslash($_POST['tone']));
                }
                if (isset($_POST['post_type'])) {
                    $post_type = sanitize_text_field(wp_unslash($_POST['post_type']));
                }

                $api_key = Skelet_Plugin_Status::get();

                $args = array('timeout' => 800,);
                $url = "https://skelet.ai/api/endpoints/skelet-api/generate-content?apiKey=$api_key&keyword=$keywords&title=$title&goal=$goal&tone=$tone";
                $response = wp_remote_get($url, $args);

                if (is_wp_error($response)) {
                    return wp_send_json_error('API request failed: ' . $response->get_error_message());
                }

                // Extract response body
                $body = wp_remote_retrieve_body($response);

                // Initialize an array to hold the content
                $content = '';

                // Split the body by 'data:' to process each segment
                $segments = explode("data: ", $body);

                foreach ($segments as $segment) {
                    // Skip empty segments
                    if (trim($segment) === '' || $segment === 'Stream done') {
                        continue;
                    }

                    // Extract JSON data from each segment
                    $data = json_decode(trim($segment), true);

                    // Append the content to the result
                    if (isset($data['content'])) {
                        $content .= $data['content'];
                    }
                }
                // Extract the first <h1> tag as the post title
                if (preg_match('/<h1[^>]*>(.*?)<\/h1>/', $content, $matches)) {
                    $post_title = sanitize_text_field($matches[1]);
                    // Remove the <h1> tag from the content
                    $content = preg_replace('/<h1[^>]*>.*?<\/h1>/', '', $content);
                } else {
                    // Fallback to the provided title if no <h1> is found
                    $post_title = $title;
                }

                // Remove all <br> tags from the content
                $content = str_replace(array('<br>', '<br/>', '<br />'), '', $content);
                if(empty($post_type)){
                    $post_type = 'post';
                }

                // Prepare the post array
                $post_data = array(
                    'post_title'   => $post_title,
                    'post_content' => $content,
                    'post_status'  => 'draft',
                    'post_author'  => get_current_user_id(),
                    'post_type'    => $post_type
                );

                // Insert the post into the database
                $post_id = wp_insert_post($post_data);

                if (is_wp_error($post_id)) {
                    return wp_send_json_error('Failed to create post: ' . $post_id->get_error_message());
                } else {
                    $post_url = get_edit_post_link($post_id, '');
                    return wp_send_json_success(array('message' => 'Post created successfully', 'redirect_url' => $post_url));
                }
            } else {
                wp_send_json_error('No title provided');
            }
        }
    }
    wp_die();
}
add_action('wp_ajax_skelet_generate_content', 'skelet_generate_content');
add_action('wp_ajax_nopriv_skelet_generate_content', 'skelet_generate_content');

function skelet_publish_exported_article(WP_REST_Request $request) {
    $wordpress_api_key = Skelet_Plugin_Status::get();
    $request_data = $request->get_json_params();
    $api_key = isset($request_data['api_key']) ? sanitize_text_field($request_data['api_key']) : null;

    if ($api_key !== $wordpress_api_key) {
        return new WP_REST_Response('Invalid API key', 403);
    }

    $post_title = isset($request_data['post_title']) ? sanitize_text_field($request_data['post_title']) : null;
    $post_content = isset($request_data['post_content']) ? sanitize_textarea_field($request_data['post_content']) : null;

    if (empty($post_title) || empty($post_content)) {
        return new WP_REST_Response('Post title and content are required', 400);
    }

    $post_data = [
        'post_title'   => $post_title,
        'post_content' => $post_content,
        'post_status'  => 'draft',  // Set post status to draft
        'post_author'  => get_current_user_id(),  // Set the author of the post
        'post_type'    => 'post',  // Default post type
    ];

    $post_id = wp_insert_post($post_data);
    if (is_wp_error($post_id)) {
        return new WP_REST_Response('Error creating the post', 500);
    } 

    $post_image_url = isset($request_data['post_image']) ? esc_url_raw($request_data['post_image']) : null;
    if (!empty($post_image_url)) {
        $image_data = file_get_contents($post_image_url); 
    
        if ($image_data === false) {
            return new WP_REST_Response('Error downloading the image', 500);
        }
    
        $upload_dir = wp_upload_dir();
        $upload_path = $upload_dir['path'] . '/' . basename($post_image_url);
    
        if (file_put_contents($upload_path, $image_data) === false) {
            return new WP_REST_Response('Error saving the image', 500);
        }
    
        $filetype = wp_check_filetype($upload_path, null);
        if (!$filetype['type']) {
            return new WP_REST_Response('Invalid file type', 400);
        }
    
        $attachment = [
            'post_mime_type' => $filetype['type'],
            'post_title'     => sanitize_file_name(basename($upload_path)),
            'post_content'   => '',
            'post_status'    => 'inherit',
        ];
    
        $attachment_id = wp_insert_attachment($attachment, $upload_path, $post_id);
        if (is_wp_error($attachment_id)) {
            return new WP_REST_Response('Error inserting the attachment: ' . $attachment_id->get_error_message(), 500);
        }
    
        require_once ABSPATH . 'wp-admin/includes/image.php';
        $attachment_metadata = wp_generate_attachment_metadata($attachment_id, $upload_path);
    
        if (is_wp_error($attachment_metadata)) {
            return new WP_REST_Response('Error generating attachment metadata: ' . $attachment_metadata->get_error_message(), 500);
        }
    
        wp_update_attachment_metadata($attachment_id, $attachment_metadata);
        set_post_thumbnail($post_id, $attachment_id);
    }

    return new WP_REST_Response('Post created successfully in draft', 200);
}

?>